#!/bin/bash
#
# Encrypt all regular files found in tmp puppet backup dir
#
# Called as part of appliance backup
#
# INPUT: These environment variables must be set for this script to run.
#    PASSWORD
#        The encryption password provided by ASM server (either typed in or
#        taken from Backup Settings) is expected to already be set in the
#        environment in $PASSWORD.
#

#
# Set to exit immediately if any command fails
#
set -e

# Validate PASSWORD environment variable
#
if [ -z $PASSWORD ]; then
    echo "PASSWORD environment variable missing"
    exit 1
fi

#
# Set our base dir. This must be the same as in /opt/Dell/scripts/backup-puppet.sh
# since that script produces the tar file for us to encrypt.
#
PUPPET_TMP_DIR=/var/tmp/backup/puppet

#
# Make sure the tmp dir exists
#
if [ ! -d "$PUPPET_TMP_DIR" ]; then
    echo "Puppet temp backup directory not found: $PUPPET_TMP_DIR"
    exit 1;
fi


#
# Find all normal files under tmp dir
#
PUPPET_BACKUP_FILES=$(find "$PUPPET_TMP_DIR" -type f)

#
# Error out if no files found
#
if [ -z "$PUPPET_BACKUP_FILES" ]; then
    echo "No files found to encrypt in Puppet backup directory $PUPPET_TMP_DIR"
    exit 1
fi


#
# Encrypt each file found
#
for BACKUP_FILE in $PUPPET_BACKUP_FILES; do
    gpg --batch -q --passphrase $PASSWORD -c $BACKUP_FILE

    # Remove tar file
    rm $BACKUP_FILE
done

echo "Successfully encrypted all puppet db files"

exit 0
